import bodyParser from "body-parser"
import config from "./config.js"
import vault from "./vault.js"

const _config = config.get()
const _title = _config.app.name

const load = (router, features) => {

	if(features.api == true) {

		router.get("/api/getlink/:publicID", (req, res, next) => {
			const link = vault.getLink(req.params.publicID)
			res.json(link)
		})
	
		router.get("/api/createOTLink/:publicID", (req, res, next) => {
			const otLink = vault.createOTLink(req.params.publicID)
			res.json(otLink)
		})
	
		router.get("/api/read/:otLinkID", (req, res, next) => {
			const secret = vault.read(req.params.otLinkID)
			res.json(secret)
		})
	
		if(features.create == true) {

			router.post("/api/create", bodyParser.urlencoded({ extended: false }), bodyParser.json(), (req, res, next) => {
				const link = vault.create(req.body)
				res.json(link)
			})

		}
	
	}

	if(features.client !== false) {

		router.get("/link/:publicID", (req, res, next) => {
			const link = vault.getLink(req.params.publicID)
			if(link) {
				router.pug(res, "link.pug", { title : _title, link: link, linkUrl: req.protocol + "://" + req.headers.host + "/link/" + link.publicID })
			} else {
				res.redirect('/')
			}
		})
		
		router.post("/requestotl", bodyParser.urlencoded({ extended: false }), bodyParser.json(), (req, res, next) => {
			const link = vault.getLink(req.body.publicID)
			if(link) {
				const otLink = vault.createOTLink(link.publicID)
				if(otLink) {
					res.json(otLink)
				} else {
					res.json(null)
				}
			} else {
				res.json(null)
			}
		})

		router.get("/read/:otLinkID", (req, res, next) => {
			const secret = vault.read(req.params.otLinkID)
			if(secret) {
				router.pug(res, "read.pug", { title : _title, secret: secret })
			} else {
				res.redirect('/')
			}
		})

		if(features.create == true) {
			
			router.get(features.createPath, (req, res, next) => {
				router.pug(res, "create.pug", { title: _title })
			})

			router.post(features.createPath, bodyParser.urlencoded({ extended: false }), bodyParser.json(), (req, res, next) => {
				const link = vault.create(req.body)
				if(link) {
					res.json(link)
				} else {
					res.json(null)
				}
			})
			
			router.post("/newlink", bodyParser.urlencoded({ extended: false }), bodyParser.json(), (req, res, next) => {
				router.pug(res, "newlink.pug", { title : _title, link: req.body, linkUrl: req.protocol + "://" + req.headers.host + "/link/" + req.body.publicID })
			})
	
		}

		router.get("/", (req, res, next) => {
			router.pug(res, "index.pug", { title: _title })
		})

	}

}

export default {
	load,
}